@@ -1,6 +1,15 @@
-use super::{MJCarousel, NAME};
+use super::{MJCarousel, MJCarouselChild, NAME};
 use crate::print_attrs_children;
 
+impl Print for MJCarouselChild {
+    fn print(&self, pretty: bool, level: usize, indent_size: usize) -> String {
+        match self {
+            Self::Comment(elt) => elt.print(pretty, level, indent_size),
+            Self::MJCarouselImage(elt) => elt.print(pretty, level, indent_size),
+        }
+    }
+}
+
 print_attrs_children!(MJCarousel, NAME);
 
 #[cfg(test)]
