@@ -1,4 +1,4 @@
-use super::{MJCarousel, NAME};
+use super::{MJCarousel, MJCarouselChild, NAME};
 use crate::helper::condition::{mso_conditional_tag, mso_negation_conditional_tag};
 use crate::helper::random;
 use crate::helper::size::{Pixel, Size};
@@ -9,6 +9,15 @@ use std::cell::{Ref, RefCell};
 use std::collections::HashMap;
 use std::rc::Rc;
 
+impl<'r, 'e: 'r, 'h: 'r> Renderable<'r, 'e, 'h> for MJCarouselChild {
+    fn renderer(&'e self, header: Rc<RefCell<Header<'h>>>) -> Box<dyn Render<'h> + 'r> {
+        match self {
+            Self::MJCarouselImage(elt) => elt.renderer(header),
+            Self::Comment(elt) => elt.renderer(header),
+        }
+    }
+}
+
 fn repeat(count: usize, value: &str) -> String {
     (0..count).map(|_idx| value).collect::<Vec<_>>().join("")
 }
@@ -355,6 +364,7 @@ impl<'e, 'h> MJCarouselRender<'e, 'h> {
             ".mj-carousel noinput .mj-carousel-image-1 { display: block !important;  }".into(),
         );
         style.push(".mj-carousel noinput .mj-carousel-arrows, .mj-carousel noinput .mj-carousel-thumbnails { display: none !important; }".into());
+        style.push("[owa] .mj-carousel-thumbnail { display: none !important; }".into());
 
         style.push(format!(
             r#"
